Observable

Type Alias Observable 

pub type Observable<D> = ObservableField<D, RefCell<Vec<UniversalSubscriber<D>>>>;
ObservableField that allows to subscribe to all changes (ObservableField::subscribe) and to concrete changes (ObservableField::when and ObservableField::when_eq).

Aliased Type

pub struct Observable<D> { /* private fields */ }

Implementations

Source

impl<D> Observable<D>
where D: Clone + 'static,

pub fn subscribe(&self) -> LocalBoxStream<'static, D>

Returns Stream into which underlying data updates will be emitted.